{*****************************************************************************
*                                                                            *
*  FGIW6.DPR                                                                 *
*  FGIW6U.PAS                                                                *
*                                                                            *
*  Demonstrate how to load a Fastgraph/Fonts font file from an FGI library.  *
*                                                                            *
*****************************************************************************}

unit Fgiw6u;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, FGWin, FGFWin, FGIWin;

type
  TForm1 = class(TForm)
    procedure AppOnActivate(Sender: TObject);
    procedure FormActivate(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormPaint(Sender: TObject);
    procedure FormResize(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
  end;

var
  Form1: TForm1;

implementation

{$R *.DFM}
var
  cxClient, cyClient : integer;
  dc   : hDC;
  hpal : hPalette;
  hvb  : integer;
  hfgi : integer;
  buffer : pointer;

procedure TForm1.AppOnActivate(Sender: TObject);
begin
  fg_realize(hpal);
  Invalidate;
end;

procedure TForm1.FormActivate(Sender: TObject);
begin
  fg_realize(hpal);
end;

procedure TForm1.FormCreate(Sender: TObject);
var
  size : longint;
begin
  dc := GetDC(Form1.Handle);
  fg_setdc(dc);
  hpal := fg_defpal;
  fg_realize(hpal);

  fg_vbinit;
  hvb := fg_vballoc(320,200);
  fg_vbopen(hvb);
  fg_vbcolors;

  hfgi := fgi_open('EXAMPLE.FGI'+chr(0));
  if hfgi = 0 then
  begin
    MessageDlg('Unable to open FGI file.',mtError,[mbOK],0);
    Application.Terminate;
    Exit;
  end;
  size := fgi_filesize('BRODWY18.FGF'+chr(0),hfgi);
  buffer := GlobalAllocPtr(GMEM_MOVEABLE,size);
  fgi_readnext(buffer^,integer(size),hfgi);
  fgi_close(hfgi);

  fgf_define(buffer^);
  fgf_justify(0,0);
  fg_setcolor(255);
  fg_fillpage;
  fg_setcolor(20);
  fg_move(160,100);
  fgf_print('BROADWAY FONT',13);

  Application.OnActivate := AppOnActivate;
end;

procedure TForm1.FormPaint(Sender: TObject);
begin
  fg_vbscale(0,fg_getmaxx,0,fg_getmaxy,0,cxClient-1,0,cyClient-1);
end;

procedure TForm1.FormResize(Sender: TObject);
begin
  cxClient := ClientWidth;
  cyClient := ClientHeight;
  Invalidate;
end;

procedure TForm1.FormDestroy(Sender: TObject);
begin
  GlobalFreePtr(buffer);
  fg_vbclose;
  fg_vbfree(hvb);
  fg_vbfin;
  DeleteObject(hpal);
  ReleaseDC(Form1.Handle,dc);
end;

end.
